@@ -1,7 +1,7 @@
 package Yars::Client;
 
 # ABSTRACT: Yet Another RESTful-Archive Service Client
-our $VERSION = '1.26'; # VERSION
+our $VERSION = '1.27'; # VERSION
 
 use strict;
 use warnings;
@@ -236,6 +236,7 @@ sub download {
         $self->tx($tx);
         my $res = $tx->success or do {
             my $error = $tx->error;
+            $tx->closed;
             if ($error->{code}) {
                 ERROR "Yars download : $error->{code} $error->{message}";
                 last;
@@ -460,7 +461,7 @@ sub upload {
         }
     }
     $self->res($tx->res);
-    return '' if !$code || !$tx->res->is_status_class(200);
+    return '' if !$code || !$tx->res->is_success;
 
     DEBUG "Response : ".$tx->res->code." ".$tx->res->message;
     return 'ok';
@@ -554,7 +555,7 @@ Yars::Client - Yet Another RESTful-Archive Service Client
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
